==> opencl-clhpp-2023.04.17-1-any.pkg.tar.xz: usr/share/doc/opencl-clhpp/navtreeindex2.js <==
var NAVTREEINDEX2 =
{
"opencl_8hpp.html#ab76105928c721c5a922a4c1aea804e87":[6,0,0,0,0,0,75],
"opencl_8hpp.html#abd957be3ad58ee2932a99ed8bc6cc049":[6,0,0,0,0,0,63],
"opencl_8hpp.html#ae48b9857ac37b027d8e946f0cf3c3232":[6,0,0,0,0,0,72],
"opencl_8hpp.html#ae97dc5bb86e2c3c3935280a86cda301c":[6,0,0,0,0,0,77],
"opencl_8hpp.html#aebc48a598e41f0cb98397460ca04ffb6":[6,0,0,0,0,0,62],
"opencl_8hpp.html#af9f49b386b20c55c04a9e6cd21849fd5":[6,0,0,0,0,0,79],
"opencl_8hpp_source.html":[6,0,0,0,0,0],
"pages.html":[],
"structcl_1_1_image_format.html":[4,0,0,18],
"structcl_1_1_image_format.html":[5,0,0,20],
"structcl_1_1_image_format.html#a039deeaa451a52448014794e7dae30ba":[5,0,0,20,1],
"structcl_1_1_image_format.html#a039deeaa451a52448014794e7dae30ba":[4,0,0,18,1],
"structcl_1_1_image_format.html#a74296cd49ed08b0521e8b6b26e51608f":[5,0,0,20,3],
"structcl_1_1_image_format.html#a74296cd49ed08b0521e8b6b26e51608f":[4,0,0,18,3],
"structcl_1_1_image_format.html#a935a0799f110ada43afb5ccfacf6197b":[5,0,0,20,2],
"structcl_1_1_image_format.html#a935a0799f110ada43afb5ccfacf6197b":[4,0,0,18,2],
"structcl_1_1_image_format.html#adf48b6e9dfdfefb7583e20826c3b4a14":[5,0,0,20,0],
"structcl_1_1_image_format.html#adf48b6e9dfdfefb7583e20826c3b4a14":[4,0,0,18,0],
"structcl_1_1_local_space_arg.html":[4,0,0,22],
"structcl_1_1_local_space_arg.html":[5,0,0,24],
"structcl_1_1_s_v_m_allocator_1_1rebind.html":[5,0,0,31,0],
"structcl_1_1_s_v_m_allocator_1_1rebind.html":[4,0,0,29,0],
"structcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4_1_1rebind.html":[5,0,0,32,0],
"structcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4_1_1rebind.html":[4,0,0,30,0],
"structcl_1_1compatibility_1_1make__kernel.html":[5,0,0,0,0],
"structcl_1_1compatibility_1_1make__kernel.html#aaa094f5455d73fae53eb99b374f05eec":[5,0,0,0,0,1],
"structcl_1_1compatibility_1_1make__kernel.html#ab5a793302f7651ad151a1e4b585be5d4":[5,0,0,0,0,0],
"structcl_1_1detail_1_1_get_info_functor0.html":[5,0,0,1,1],
"structcl_1_1detail_1_1_get_info_functor1.html":[5,0,0,1,2],
"structcl_1_1detail_1_1_kernel_argument_handler.html":[5,0,0,1,3],
"structcl_1_1detail_1_1_kernel_argument_handler_3_01_local_space_arg_00_01void_01_4.html":[5,0,0,1,5],
"structcl_1_1detail_1_1_kernel_argument_handler_3_01_t_00_01typename_01std_1_1enable__if_3_01std_cb5bfaca8096193f715a7bbe8a3fa84f.html":[5,0,0,1,6],
"structcl_1_1detail_1_1_kernel_argument_handler_3_01_t_00_01typename_01std_1_1enable__if_3_9std_10affa824618af864313998f2e6bcf08f.html":[5,0,0,1,7],
"structcl_1_1detail_1_1_kernel_argument_handler_3_01cl_1_1_device_command_queue_00_01void_01_4.html":[5,0,0,1,4],
"structcl_1_1detail_1_1_reference_handler.html":[5,0,0,1,9],
"structcl_1_1detail_1_1_reference_handler_3_01cl__command__queue_01_4.html":[5,0,0,1,10],
"structcl_1_1detail_1_1_reference_handler_3_01cl__context_01_4.html":[5,0,0,1,11],
"structcl_1_1detail_1_1_reference_handler_3_01cl__device__id_01_4.html":[5,0,0,1,12],
"structcl_1_1detail_1_1_reference_handler_3_01cl__event_01_4.html":[5,0,0,1,13],
"structcl_1_1detail_1_1_reference_handler_3_01cl__kernel_01_4.html":[5,0,0,1,14],
"structcl_1_1detail_1_1_reference_handler_3_01cl__mem_01_4.html":[5,0,0,1,15],
"structcl_1_1detail_1_1_reference_handler_3_01cl__platform__id_01_4.html":[5,0,0,1,16],
"structcl_1_1detail_1_1_reference_handler_3_01cl__program_01_4.html":[5,0,0,1,17],
"structcl_1_1detail_1_1_reference_handler_3_01cl__sampler_01_4.html":[5,0,0,1,18],
"structcl_1_1detail_1_1param__traits.html":[5,0,0,1,8]
};

==> opencl-clhpp-2024.05.08-1-any.pkg.tar.xz: usr/share/doc/opencl-clhpp/navtreeindex2.js <==
var NAVTREEINDEX2 =
{
"namespacecl.html#a43fd451f30944f957126b167b4eb0664":[4,0,0,40],
"namespacecl.html#a445d7d2f4c3234dc5fbd2d254eb39e22":[4,0,0,38],
"namespacecl.html#a640c02cb285c5ab57ab8669bc2146643":[4,0,0,46],
"namespacecl.html#a85686c89497c3ef296e3cf1840d7d725":[4,0,0,47],
"namespacecl.html#a8e1fce10cd1b8118f51aa91ce0a589e5":[4,0,0,41],
"namespacecl.html#a9835d1b49011a71e71b602c8b4db261e":[4,0,0,49],
"namespacecl.html#ab2784dad151e0aed0685067d190dc994":[4,0,0,50],
"namespacecl.html#ab76105928c721c5a922a4c1aea804e87":[4,0,0,51],
"namespacecl.html#ae48b9857ac37b027d8e946f0cf3c3232":[4,0,0,48],
"namespacecl.html#ae97dc5bb86e2c3c3935280a86cda301c":[4,0,0,53],
"namespacecl.html#af9f49b386b20c55c04a9e6cd21849fd5":[4,0,0,55],
"namespacemembers.html":[4,1,0],
"namespacemembers_func.html":[4,1,1],
"namespacemembers_type.html":[4,1,2],
"namespaces.html":[4,0],
"opencl_8hpp.html":[6,0,0,0,0,0],
"opencl_8hpp.html#a02c4368c6ce7a1a99132eafd5dc96fa9":[6,0,0,0,0,0,67],
"opencl_8hpp.html#a05791e9d5da23b21abd6e319fb262c9f":[6,0,0,0,0,0,66],
"opencl_8hpp.html#a1197a833cdd6664f206b079f2bebd2eb":[6,0,0,0,0,0,69],
"opencl_8hpp.html#a2903d8ce897eef7efca4ab6f32f2a197":[6,0,0,0,0,0,63],
"opencl_8hpp.html#a2f71ed9a316daf59c03c0f3ba62f1bd3":[6,0,0,0,0,0,68],
"opencl_8hpp.html#a2f9d06d8196d7a2f4cf196d5bb7e5dd0":[6,0,0,0,0,0,76],
"opencl_8hpp.html#a2fc824c118740089633cc15e7107f3f0":[6,0,0,0,0,0,78],
"opencl_8hpp.html#a43fd451f30944f957126b167b4eb0664":[6,0,0,0,0,0,64],
"opencl_8hpp.html#a445d7d2f4c3234dc5fbd2d254eb39e22":[6,0,0,0,0,0,62],
"opencl_8hpp.html#a640c02cb285c5ab57ab8669bc2146643":[6,0,0,0,0,0,70],
"opencl_8hpp.html#a85686c89497c3ef296e3cf1840d7d725":[6,0,0,0,0,0,71],
"opencl_8hpp.html#a8e1fce10cd1b8118f51aa91ce0a589e5":[6,0,0,0,0,0,65],
"opencl_8hpp.html#a9835d1b49011a71e71b602c8b4db261e":[6,0,0,0,0,0,73],
"opencl_8hpp.html#ab2784dad151e0aed0685067d190dc994":[6,0,0,0,0,0,74],
"opencl_8hpp.html#ab76105928c721c5a922a4c1aea804e87":[6,0,0,0,0,0,75],
"opencl_8hpp.html#ae48b9857ac37b027d8e946f0cf3c3232":[6,0,0,0,0,0,72],
"opencl_8hpp.html#ae97dc5bb86e2c3c3935280a86cda301c":[6,0,0,0,0,0,77],
"opencl_8hpp.html#af9f49b386b20c55c04a9e6cd21849fd5":[6,0,0,0,0,0,79],
"opencl_8hpp_source.html":[6,0,0,0,0,0],
"pages.html":[],
"structcl_1_1_image_format.html":[4,0,0,18],
"structcl_1_1_image_format.html":[5,0,0,20],
"structcl_1_1_image_format.html#a039deeaa451a52448014794e7dae30ba":[5,0,0,20,1],
"structcl_1_1_image_format.html#a039deeaa451a52448014794e7dae30ba":[4,0,0,18,1],
"structcl_1_1_image_format.html#a74296cd49ed08b0521e8b6b26e51608f":[5,0,0,20,3],
"structcl_1_1_image_format.html#a74296cd49ed08b0521e8b6b26e51608f":[4,0,0,18,3],
"structcl_1_1_image_format.html#a935a0799f110ada43afb5ccfacf6197b":[5,0,0,20,2],
"structcl_1_1_image_format.html#a935a0799f110ada43afb5ccfacf6197b":[4,0,0,18,2],
"structcl_1_1_image_format.html#adf48b6e9dfdfefb7583e20826c3b4a14":[5,0,0,20,0],
"structcl_1_1_image_format.html#adf48b6e9dfdfefb7583e20826c3b4a14":[4,0,0,18,0],
"structcl_1_1_local_space_arg.html":[4,0,0,22],
"structcl_1_1_local_space_arg.html":[5,0,0,24],
"structcl_1_1_s_v_m_allocator_1_1rebind.html":[5,0,0,31,0],
"structcl_1_1_s_v_m_allocator_1_1rebind.html":[4,0,0,29,0],
"structcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4_1_1rebind.html":[5,0,0,32,0],
"structcl_1_1_s_v_m_allocator_3_01void_00_01_s_v_m_trait_01_4_1_1rebind.html":[4,0,0,30,0],
"structcl_1_1compatibility_1_1make__kernel.html":[5,0,0,0,0],
"structcl_1_1compatibility_1_1make__kernel.html#aaa094f5455d73fae53eb99b374f05eec":[5,0,0,0,0,1],
"structcl_1_1compatibility_1_1make__kernel.html#ab5a793302f7651ad151a1e4b585be5d4":[5,0,0,0,0,0],
"structcl_1_1detail_1_1_get_info_functor0.html":[5,0,0,1,1],
"structcl_1_1detail_1_1_get_info_functor1.html":[5,0,0,1,2],
"structcl_1_1detail_1_1_kernel_argument_handler.html":[5,0,0,1,3],
"structcl_1_1detail_1_1_kernel_argument_handler_3_01_local_space_arg_00_01void_01_4.html":[5,0,0,1,5],
"structcl_1_1detail_1_1_kernel_argument_handler_3_01_t_00_01typename_01std_1_1enable__if_3_01std_cb5bfaca8096193f715a7bbe8a3fa84f.html":[5,0,0,1,6],
"structcl_1_1detail_1_1_kernel_argument_handler_3_01_t_00_01typename_01std_1_1enable__if_3_9std_10affa824618af864313998f2e6bcf08f.html":[5,0,0,1,7],
"structcl_1_1detail_1_1_kernel_argument_handler_3_01cl_1_1_device_command_queue_00_01void_01_4.html":[5,0,0,1,4],
"structcl_1_1detail_1_1_reference_handler.html":[5,0,0,1,9],
"structcl_1_1detail_1_1_reference_handler_3_01cl__command__queue_01_4.html":[5,0,0,1,10],
"structcl_1_1detail_1_1_reference_handler_3_01cl__context_01_4.html":[5,0,0,1,11],
"structcl_1_1detail_1_1_reference_handler_3_01cl__device__id_01_4.html":[5,0,0,1,12],
"structcl_1_1detail_1_1_reference_handler_3_01cl__event_01_4.html":[5,0,0,1,13],
"structcl_1_1detail_1_1_reference_handler_3_01cl__kernel_01_4.html":[5,0,0,1,14],
"structcl_1_1detail_1_1_reference_handler_3_01cl__mem_01_4.html":[5,0,0,1,15],
"structcl_1_1detail_1_1_reference_handler_3_01cl__platform__id_01_4.html":[5,0,0,1,16],
"structcl_1_1detail_1_1_reference_handler_3_01cl__program_01_4.html":[5,0,0,1,17],
"structcl_1_1detail_1_1_reference_handler_3_01cl__sampler_01_4.html":[5,0,0,1,18],
"structcl_1_1detail_1_1param__traits.html":[5,0,0,1,8]
};
